@@ -30,8 +30,8 @@ sub wordlist {
     $eos++ while $text =~ /$eos/;
     my $is_newline = sub { $_ eq $eos };
 
-    my $mecab = [ 'mecab', '--node-format', '%M\\n', '--eos-format', "$eos\\n" ];
-    my $result = $obj->command($mecab)->setstdin($text)->update->data;
+    my @mecab = ('mecab', '--node-format', '%M\\n', '--eos-format', "$eos\\n");
+    my $result = $obj->command(@mecab)->setstdin($text)->update->data;
     warn $result =~ s/^/MECAB: /mgr if $debug;
     do {
 	map  { $is_newline->() ? "\n" : $_ }
